function ifo = IFOModel_Aplus
  % Modified GWINC model for room-temperature Voyager
  
  % start with base model
  ifo = IFOModel;
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Adjust IFO parameters
  
  % set laser power
  ifo.Laser.Power = 125;
  
  % add Newtonian Noise cancellation?
  ifo.Seismic.Omicron = 1;
  
  % Optics
  ifo.Optics.SRM.Transmittance  = 0.15;     % Transmittance of SRM  
  ifo.Optics.SRM.Tunephase = 0.0;           % SRM tuning
  ifo.Optics.Quadrature.dc = pi/2;          % demod/detection/homodyne phase
  
  % tweak suspensions?  not worth it.
  %ifo.Suspension.Fiber.Radius = 150e-6;     %   and a bit thinner (was 200)
  
  % coatings... assume we find something a bit better
  ifo.Materials.Coating.Phihighn = 1e-4;    % 2-3e-4 for Ti:Ta 
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Squeezer Parameters
  
  % Define the squeezing you want:
  %   None = ignore the squeezer settings
  %   Freq Independent = nothing special (no filter cavties)
  %   Freq Dependent = applies the specified filter cavites
  ifo.Squeezer.Type = 'Freq Dependent';
  ifo.Squeezer.AmplitudedB = 12;             % SQZ amplitude [dB]
  ifo.Squeezer.SQZAngle = 0;                 % SQZ phase [radians]
  ifo.Squeezer.LOAngleRMS = 20e-3;           % quadrature noise [radians]

  % with these losses (10%, 10%, 20ppm) and 12dB in, 6dB are measured at 5kHz
  ifo.Squeezer.InjectionLoss = 0.10;         % power loss after squeezer
  ifo.Optics.PhotoDetectorEfficiency = 0.90; % 1 - readout loss
  ifo.Optics.Loss = 20e-6;                  % was 37.5ppm 
  ifo.Optics.BSLoss = 1e-4;                 % was 2e-3
  
  % Parameters for frequency dependent squeezing
  fcParams.L = 16;            % cavity length
  fcParams.Lrt = 8e-6;       % round-trip loss in the cavity
  fcParams.Te = 1e-6;          % end mirror trasmission
  fcParams.Rot = deg2rad(0);   % phase rotation after cavity (why?)
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Parameter based computations
  
  % compute ifo info for use in filter cavity calculation
  ifo = precompIFO(ifo);
  
  % compute input mirror transmission and detuning
  ifo.Squeezer.FilterCavity = computeFCParams(ifo, fcParams);
end
